@@ -1221,7 +1221,7 @@ class PatientVaccination(ModelSQL, ModelView):
         domain=[('is_institution', '=', True)],
         help='Medical Center where the patient is being or was vaccinated')
     date = fields.DateTime('Date')
-    dose = fields.Integer('Dose Number')
+    dose = fields.Integer('Dose #')
     next_dose_date = fields.DateTime('Next Dose')
     observations = fields.Char('Observations')
 
@@ -1806,11 +1806,14 @@ class HospitalBed(ModelSQL, ModelView):
         ('reserved', 'Reserved'),
         ('occupied', 'Occupied'),
         ('na', 'Not available'),
-        ), 'Status', sort=False)
+        ), 'Status', readonly=True, sort=False)
 
     def default_bed_type(self):
         return 'gatch'
 
+    def default_state(self):
+        return 'free'
+
     def get_rec_name(self, ids, name):
         if not ids:
             return {}
