@@ -24,6 +24,7 @@ from trytond.model import ModelView, ModelSingleton, ModelSQL, fields
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 from trytond.pyson import Eval, Not, Bool, And, Equal
+from datetime import datetime
 
 
 class InpatientSequences(ModelSingleton, ModelSQL, ModelView):
@@ -79,39 +80,56 @@ class InpatientRegistration(ModelSQL, ModelView):
 # Method to check for availability and make the hospital bed reservation
 
     def button_registration_confirm(self, ids):
-        cursor = Transaction().cursor
+		registration_id = self.browse(ids)[0]
+		bed_obj = Pool().get('gnuhealth.hospital.bed')
+		cursor = Transaction().cursor
+		bed_id = registration_id.bed.id
+		cursor.execute("SELECT COUNT(*) \
+			FROM gnuhealth_inpatient_registration \
+			WHERE (hospitalization_date::timestamp,discharge_date::timestamp) \
+				OVERLAPS (timestamp %s, timestamp %s) \
+			  AND (state = %s or state = %s) \
+			  AND bed = CAST(%s AS INTEGER) ",
+			(registration_id.hospitalization_date, registration_id.discharge_date,
+			'confirmed','hospitalized', str(bed_id)))
 
-        for reservation in self.browse(ids):
-            bed_id = str(reservation.bed.id)
+		res = cursor.fetchone()
+		
+		if res[0] > 0:
+			self.raise_user_error('bed_is_not_available')
+		else:
+			self.write(ids, {'state': 'confirmed'})
+			bed_obj.write(registration_id.bed.id, {'state': 'reserved'})
 
-            cursor.execute("SELECT COUNT(*) \
-                FROM gnuhealth_inpatient_registration \
-                WHERE (hospitalization_date::timestamp,discharge_date::timestamp) \
-                    OVERLAPS (timestamp %s, timestamp %s) \
-                  AND state = %s \
-                  AND bed = CAST(%s AS INTEGER) ",
-                (reservation.hospitalization_date, reservation.discharge_date,
-                'confirmed', bed_id))
-
-            res = cursor.fetchone()
-
-        if res[0] > 0:
-            self.raise_user_error('bed_is_not_available')
-        else:
-            self.write(ids, {'state': 'confirmed'})
-
-        return True
+		return True
 
     def button_patient_discharge(self, ids):
+        registration_id = self.browse(ids)[0]
+        bed_obj = Pool().get('gnuhealth.hospital.bed')
+
         self.write(ids, {'state': 'free'})
+        bed_obj.write(registration_id.bed.id, {'state': 'free'})
         return True
 
     def button_registration_cancel(self, ids):
+        registration_id = self.browse(ids)[0]
+        bed_obj = Pool().get('gnuhealth.hospital.bed')
+
         self.write(ids, {'state': 'cancelled'})
+        bed_obj.write(registration_id.bed.id, {'state': 'free'})
         return True
 
     def button_registration_admission(self, ids):
-        self.write(ids, {'state': 'hospitalized'})
+        registration_id = self.browse(ids)[0]
+        bed_obj = Pool().get('gnuhealth.hospital.bed')
+        
+        if ( registration_id.hospitalization_date.date() <> datetime.today().date()):
+            self.raise_user_error ("The Admission date must be today")
+        else:
+            self.write(ids, {'state': 'hospitalized'})
+
+            bed_obj.write(registration_id.bed.id, {'state': 'occupied'})
+            
         return True
 
     def create(self, values):
@@ -130,9 +148,6 @@ class InpatientRegistration(ModelSQL, ModelView):
         return 'free'
 
 
-
-
-
     def __init__(self):
         super(InpatientRegistration, self).__init__()
 
@@ -162,6 +177,10 @@ class InpatientRegistration(ModelSQL, ModelView):
                 'button_patient_discharge': {
                     'invisible': Not(Equal(Eval('state'), 'hospitalized')),
                     },
+
+                'button_registration_admission': {
+                    'invisible': Not(Equal(Eval('state'), 'confirmed')),
+                    },
                     
                 })
 
