@@ -1,24 +1,24 @@
-# coding=utf-8
-
-#    Copyright (C) 2008-2012  Luis Falcon
-
+# -*- coding: utf-8 -*-
+##############################################################################
+#
+#    GNU Health: The Free Health and Hospital Information System
+#    Copyright (C) 2008-2012  Luis Falcon <lfalcon@gnusolidario.org>
+#
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation, either version 3 of the License, or
 #    (at your option) any later version.
-
+#
 #    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #    GNU General Public License for more details.
-
+#
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-from trytond.model import ModelView, ModelSingleton, ModelSQL, fields
-from trytond.tools import safe_eval, datetime_strftime
-from trytond.transaction import Transaction
-from trytond.pyson import Eval
+#
+##############################################################################
+from trytond.model import ModelView, ModelSQL, fields
 
 
 class Surgery(ModelSQL, ModelView):
@@ -39,22 +39,22 @@ class Surgery(ModelSQL, ModelView):
         ('o', 'Optional'),
         ('r', 'Required'),
         ('u', 'Urgent'),
-        ], 'Surgery Classification', select='1')
+        ], 'Classification', sort=False)
     surgeon = fields.Many2One('gnuhealth.physician', 'Surgeon',
         help="Surgeon who did the procedure")
     anesthetist = fields.Many2One('gnuhealth.physician', 'Anesthetist',
         help="Anesthetist in charge")
-    date = fields.DateTime('Date of the surgery')
+    date = fields.DateTime('Date')
     age = fields.Char('Patient age',
         help="Patient age at the moment of the surgery. Can be estimative")
-    description = fields.Char('Description')
+    description = fields.Char('Description', required = True)
     preop_mallampati = fields.Selection([
-        ('Class 1', 'Full visibility of tonsils, uvula and soft palate'),
-        ('Class 2', 'Visibility of hard and soft palate, ' \
+        ('Class 1', 'Class 1: Full visibility of tonsils, uvula and soft palate'),
+        ('Class 2', 'Class 2: Visibility of hard and soft palate, ' \
                     'upper portion of tonsils and uvula'),
-        ('Class 3', 'Soft and hard palate and base of the uvula are visible'),
-        ('Class 4', 'Only Hard Palate visible'),
-        ], 'Mallampati Score', select='1')
+        ('Class 3', 'Class 3: Soft and hard palate and base of the uvula are visible'),
+        ('Class 4', 'Class 4: Only Hard Palate visible'),
+        ], 'Mallampati Score', sort=False)
     preop_bleeding_risk = fields.Boolean('Risk of Massive bleeding',
         help="Check this box if patient has a risk of loosing more than 500 " \
         "ml in adults of over 7ml/kg in infants. If so, make sure that " \
@@ -80,7 +80,7 @@ class MedicalOperation(ModelSQL, ModelView):
 
     name = fields.Many2One('gnuhealth.surgery', 'Surgery')
     procedure = fields.Many2One('gnuhealth.procedure', 'Code', required=True,
-        select="1",
+        select=True,
         help="Procedure Code, for example ICD-10-PCS Code 7-character string")
     notes = fields.Text('Notes')
 
